﻿# Quelle: https://msdn.microsoft.com/en-us/powershell/dsc/reportserver

function GetReport
{
    param (
        $AgentId = "$((glcm).AgentId)", 
        $serviceURL = "http://DSC-PS01:8080/PSDSCPullServer.svc"
        )
    $requestUri = "$serviceURL/Nodes(AgentId= '$AgentId')/Reports"
    $request = Invoke-WebRequest -Uri $requestUri `
               -ContentType "application/json;odata=minimalmetadata;streaming=true;charset=utf-8" `
               -UseBasicParsing -Headers @{Accept = "application/json";ProtocolVersion = "2.0"} `
               -ErrorAction SilentlyContinue -ErrorVariable ev
    $object = ConvertFrom-Json $request.content
    return $object.value
}

#region - Ermitteln der AgentID des Pull Clients DSC-PC01

$VMname = "DSC-PC01"
# Zum Ermitteln der AgentID verbinden wir uns per Powershell Direkt mit dem Pull Client
# ==> Dazu müssen wir uns dort als lokaler Administrator anmelden
$cred = Get-Credential -Message "Anmelden am Pull Client $VMname" -UserName "Administrator"
$AgentID = Invoke-Command -VMName DSC-PC01 -Credential $cred -ScriptBlock { (glcm).AgentId }

# Jetzt die Reüprtdaten abrufen
$reports = GetReport -AgentId $AgentID
# ... absteigend nach Datum sortieren 
$reportsByStartTime = $reports | Sort-Object {$_."StartTime" -as [DateTime] } -Descending
# ... die neuesten Daten herauspicken
$reportMostRecent = $reportsByStartTime[0]
# ... aus dem JSON-Format konvertieren
$statusData = $reportMostRecent.StatusData | ConvertFrom-Json
# ... und anzeigen
$statusData.ResourcesInDesiredState
$statusData.ResourcesNotInDesiredState    # diese Liste sollte leer sein!

#endregion
